@@ -1,8 +1,6 @@
 package Bread::Board;
-BEGIN {
-  $Bread::Board::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+$Bread::Board::VERSION = '0.34';
 use strict;
 use warnings;
 use Carp qw(confess);
@@ -262,7 +260,7 @@ Bread::Board - A solderless way to wire up your application components
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -761,7 +759,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
