@@ -1,33 +1,19 @@
 package Bread::Board::ConstructorInjection;
-BEGIN {
-  $Bread::Board::ConstructorInjection::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::ConstructorInjection::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: service instantiating objects via a constructor
+$Bread::Board::ConstructorInjection::VERSION = '0.34';
 use Moose;
 
 use Try::Tiny;
 
 use Bread::Board::Types;
 
-with 'Bread::Board::Service::WithClass',
+with 'Bread::Board::Service::WithConstructor',
      'Bread::Board::Service::WithParameters',
      'Bread::Board::Service::WithDependencies';
 
-has 'constructor_name' => (
-    is       => 'rw',
-    isa      => 'Str',
-    lazy     => 1,
-    builder  => '_build_constructor_name',
-);
-
 has '+class' => (required => 1);
 
-sub _build_constructor_name {
-    my $self = shift;
-
-    try { Class::MOP::class_of($self->class)->constructor_name } || 'new';
-}
-
 sub get {
     my $self = shift;
 
@@ -47,11 +33,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::ConstructorInjection
+Bread::Board::ConstructorInjection - service instantiating objects via a constructor
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -102,7 +88,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
