@@ -1,8 +1,7 @@
 package Bread::Board::Container;
-BEGIN {
-  $Bread::Board::Container::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Container::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: A container for services and other containers
+$Bread::Board::Container::VERSION = '0.34';
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
 use MooseX::Params::Validate 0.14;
@@ -193,11 +192,46 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Container
+Bread::Board::Container - A container for services and other containers
 
 =head1 VERSION
 
-version 0.33
+version 0.34
+
+=head1 SYNOPSIS
+
+  use Bread::Board;
+  my $c = container MCP => as {
+      container Users => as {
+          service flynn => ...;
+          service bradley => ...;
+          service dillinger => ...;
+      };
+
+      container Programs => as {
+          container Rebels => as {
+              service tron => ...;
+              service yori => ...;
+              alias flynn => '/Users/flynn';
+          };
+
+          # nested container
+          container Slaves => as {
+              service sark => ...;
+              service crom => ...;
+          };
+      };
+  };
+
+  # OR directly...
+  my $guardians => Bread::Board::Container->new( name => 'Guardians' );
+  $guardians->add_service(
+      Bread::Board::ConstructorInjection->new(
+          name => 'dumont',
+          ...,
+      )
+  );
+  $c->get_sub_container('Programs')->add_sub_container($guardians);
 
 =head1 DESCRIPTION
 
@@ -390,7 +424,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
