@@ -1,8 +1,7 @@
 package Bread::Board::Container::FromParameterized;
-BEGIN {
-  $Bread::Board::Container::FromParameterized::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Container::FromParameterized::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: container with weak parent reference
+$Bread::Board::Container::FromParameterized::VERSION = '0.34';
 use Moose;
 
 extends 'Bread::Board::Container';
@@ -23,11 +22,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Container::FromParameterized
+Bread::Board::Container::FromParameterized - container with weak parent reference
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -54,7 +53,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
