@@ -1,8 +1,6 @@
 package Bread::Board::Container::Parameterized;
-BEGIN {
-  $Bread::Board::Container::Parameterized::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Container::Parameterized::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+$Bread::Board::Container::Parameterized::VERSION = '0.34';
 use Moose;
 use Moose::Util 'find_meta';
 use Bread::Board::Container::FromParameterized;
@@ -114,7 +112,7 @@ Bread::Board::Container::Parameterized - A parameterized container
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -208,7 +206,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
