@@ -1,8 +1,7 @@
 package Bread::Board::Dumper;
-BEGIN {
-  $Bread::Board::Dumper::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Dumper::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: Pretty printer for visualizing the layout of your Bread::Board
+$Bread::Board::Dumper::VERSION = '0.34';
 use Moose;
 
 sub dump {
@@ -53,11 +52,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Dumper
+Bread::Board::Dumper - Pretty printer for visualizing the layout of your Bread::Board
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -101,7 +100,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
