@@ -1,8 +1,7 @@
 package Bread::Board::LifeCycle;
-BEGIN {
-  $Bread::Board::LifeCycle::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::LifeCycle::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: base lifecycle role 
+$Bread::Board::LifeCycle::VERSION = '0.34';
 use Moose::Role;
 
 no Moose::Role; 1;
@@ -15,11 +14,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::LifeCycle
+Bread::Board::LifeCycle - base lifecycle role 
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -44,7 +43,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
