@@ -1,8 +1,7 @@
 package Bread::Board::LifeCycle::Singleton;
-BEGIN {
-  $Bread::Board::LifeCycle::Singleton::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::LifeCycle::Singleton::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: service role for singleton lifecycle
+$Bread::Board::LifeCycle::Singleton::VERSION = '0.34';
 use Moose::Role;
 
 use Try::Tiny;
@@ -68,11 +67,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::LifeCycle::Singleton
+Bread::Board::LifeCycle::Singleton - service role for singleton lifecycle
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -122,7 +121,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
