@@ -1,8 +1,7 @@
 package Bread::Board::LifeCycle::Singleton::WithParameters;
-BEGIN {
-  $Bread::Board::LifeCycle::Singleton::WithParameters::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::LifeCycle::Singleton::WithParameters::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: singleton lifecycle role for a parameterized service
+$Bread::Board::LifeCycle::Singleton::WithParameters::VERSION = '0.34';
 use Moose::Role;
 
 with 'Bread::Board::LifeCycle';
@@ -58,11 +57,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::LifeCycle::Singleton::WithParameters
+Bread::Board::LifeCycle::Singleton::WithParameters - singleton lifecycle role for a parameterized service
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -110,7 +109,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
