@@ -1,8 +1,7 @@
 package Bread::Board::Service;
-BEGIN {
-  $Bread::Board::Service::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Service::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: Base service role
+$Bread::Board::Service::VERSION = '0.34';
 use Moose::Role;
 use Module::Runtime ();
 
@@ -125,11 +124,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Service
+Bread::Board::Service - Base service role
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -231,7 +230,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
