@@ -1,8 +1,7 @@
 package Bread::Board::Service::Alias;
-BEGIN {
-  $Bread::Board::Service::Alias::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Service::Alias::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: aliases another service
+$Bread::Board::Service::Alias::VERSION = '0.34';
 use Moose;
 
 use Try::Tiny;
@@ -49,11 +48,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Service::Alias
+Bread::Board::Service::Alias - aliases another service
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -89,7 +88,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
