@@ -1,8 +1,7 @@
 package Bread::Board::Service::Deferred;
-BEGIN {
-  $Bread::Board::Service::Deferred::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Service::Deferred::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: Helper for holding a service that is not quite constructed yet
+$Bread::Board::Service::Deferred::VERSION = '0.34';
 use Moose ();
 
 use overload
@@ -92,11 +91,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Service::Deferred
+Bread::Board::Service::Deferred - Helper for holding a service that is not quite constructed yet
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -130,7 +129,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
