@@ -1,8 +1,7 @@
 package Bread::Board::Service::Inferred;
-BEGIN {
-  $Bread::Board::Service::Inferred::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Service::Inferred::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: Helper for inferring a service from a Moose object
+$Bread::Board::Service::Inferred::VERSION = '0.34';
 use Moose;
 use Moose::Util::TypeConstraints 'find_type_constraint';
 
@@ -221,11 +220,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Service::Inferred
+Bread::Board::Service::Inferred - Helper for inferring a service from a Moose object
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -252,7 +251,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
