@@ -1,8 +1,7 @@
 package Bread::Board::Service::WithDependencies;
-BEGIN {
-  $Bread::Board::Service::WithDependencies::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Service::WithDependencies::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: Services with dependencies
+$Bread::Board::Service::WithDependencies::VERSION = '0.34';
 use Moose::Role;
 
 use Try::Tiny;
@@ -112,11 +111,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Service::WithDependencies
+Bread::Board::Service::WithDependencies - Services with dependencies
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -232,7 +231,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
