@@ -1,8 +1,7 @@
 package Bread::Board::Service::WithParameters;
-BEGIN {
-  $Bread::Board::Service::WithParameters::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Service::WithParameters::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: Services with parameters
+$Bread::Board::Service::WithParameters::VERSION = '0.34';
 use Moose::Role;
 use MooseX::Params::Validate qw(validated_hash);
 
@@ -82,11 +81,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Service::WithParameters
+Bread::Board::Service::WithParameters - Services with parameters
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -183,7 +182,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
