@@ -1,8 +1,7 @@
 package Bread::Board::Traversable;
-BEGIN {
-  $Bread::Board::Traversable::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Traversable::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: role for traversing a container service tree
+$Bread::Board::Traversable::VERSION = '0.34';
 use Moose::Role;
 
 with 'MooseX::Clone' => { -version => 0.05 };
@@ -116,11 +115,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Traversable
+Bread::Board::Traversable - role for traversing a container service tree
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -189,7 +188,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
