@@ -1,8 +1,7 @@
 package Bread::Board::Types;
-BEGIN {
-  $Bread::Board::Types::AUTHORITY = 'cpan:STEVAN';
-}
-$Bread::Board::Types::VERSION = '0.33';
+our $AUTHORITY = 'cpan:STEVAN';
+# ABSTRACT: types and coercions for Bread::Board
+$Bread::Board::Types::VERSION = '0.34';
 use Moose::Util::TypeConstraints;
 
 use Scalar::Util qw(blessed);
@@ -112,11 +111,11 @@ __END__
 
 =head1 NAME
 
-Bread::Board::Types
+Bread::Board::Types - types and coercions for Bread::Board
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
@@ -247,7 +246,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive.
+This software is copyright (c) 2016 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
